Plot
Setting
Data
Axes
Info
Style
Code
NOTE: Options selected from this tab only apply to subplot 1.
Chart Type
Data
Set X and Y individually
X-axis Value
Y-axis Value
Hue
Bins
Kde
Stat

Sort
Order
Sort by
Hue condition
Text

User Option
X Limit
Y Limit

X ticks
Ticks
Rotation
Remove X ticks
Y ticks
Ticks
Rotation
Remove Y ticks
Title
X Label
Y Label

Show values Show values on the top of bar
Decimal place

Legend
Color
Use Color

Grid

Marker
Chart Preview Sampling
Auto Refresh